@@ -17,18 +17,20 @@
 
 #' Prior distributions and options
 #' 
-#' The functions described on this page are used to specify the prior-related
+#' The functions described on this page are used to specify the prior-related 
 #' arguments of the various modeling functions in the \pkg{rstanarm} package (to
 #' view the priors used for an existing model see \code{\link{prior_summary}}). 
-#' The default priors used in the various \pkg{rstanarm} modeling functions are
-#' intended to be \emph{weakly informative} in that they provide moderate
-#' regularlization and help stabilize computation. For many applications the
-#' defaults will perform well, but prudent use of more informative priors is
-#' encouraged. Uniform prior distributions are possible (e.g. by setting
-#' \code{\link{stan_glm}}'s \code{prior} argument to \code{NULL}) but, unless
-#' the data is very strong, they are not recommended and are \emph{not}
-#' non-informative, giving the same probability mass to implausible values as
-#' plausible ones.
+#' More information on priors is also available in the \emph{Prior 
+#' Distributions} vignette as well as the vignettes for the various modeling 
+#' functions. The default priors used in the various \pkg{rstanarm} modeling
+#' functions are intended to be \emph{weakly informative} in that they provide
+#' moderate regularlization and help stabilize computation. For many
+#' applications the defaults will perform well, but prudent use of more
+#' informative priors is encouraged. Uniform prior distributions are possible
+#' (e.g. by setting \code{\link{stan_glm}}'s \code{prior} argument to
+#' \code{NULL}) but, unless the data is very strong, they are not recommended
+#' and are \emph{not} non-informative, giving the same probability mass to
+#' implausible values as plausible ones.
 #' 
 #' @name priors
 #' @param location Prior location. In most cases, this is the prior mean, but
@@ -48,9 +50,9 @@
 #'   freedom parameter(s) default to \eqn{3}. For the \code{product_normal} 
 #'   prior, the degrees of freedom parameter must be an integer (vector) that is
 #'   at least \eqn{2} (the default).
-#' @param global_df,global_scale Optional arguments for the hierarchical
-#'   shrinkage priors. See the \emph{Hierarchical shrinkage family} section
-#'   below.
+#' @param global_df,global_scale,slab_df,slab_scale Optional arguments for the
+#'   hierarchical shrinkage priors. See the \emph{Hierarchical shrinkage family}
+#'   section below.
 #' @param what A character string among \code{'mode'} (the default),
 #'   \code{'mean'}, \code{'median'}, or \code{'log'} indicating how the
 #'   \code{location} parameter is interpreted in the \code{LKJ} case. If
@@ -105,8 +107,8 @@
 #' \subsection{Hierarchical shrinkage family}{
 #'   Family members:
 #'   \itemize{
-#'   \item \code{hs(df, global_df, global_scale)}
-#'   \item \code{hs_plus(df1, df2, global_df, global_scale)}
+#'   \item \code{hs(df, global_df, global_scale, slab_df, slab_scale)}
+#'   \item \code{hs_plus(df1, df2, global_df, global_scale, slab_df, slab_scale)}
 #'   }
 #'   
 #'   The hierarchical shrinkage priors are normal with a mean of zero and a 
@@ -115,21 +117,15 @@
 #'   distributed half Cauchy with a median of zero and a scale parameter that is
 #'   also half Cauchy. This is called the "horseshoe prior". The hierarchical 
 #'   shrinkage (\code{hs}) prior in the \pkg{rstanarm} package instead utilizes 
-#'   a half Student t distribution for the standard deviation (with 3 degrees of
-#'   freedom by default), as described by Piironen and Vehtari (2015). It is
-#'   possible to change the \code{df} argument, the prior degrees of freedom, to
-#'   obtain less or more shrinkage. Traditionally the standard deviation
-#'   parameter is then scaled by the square root of a \emph{global} half Cauchy 
-#'   parameter, although \pkg{rstanarm} allows setting \code{global_df} and 
-#'   \code{global_scale} arguments, in which case this global parameter is 
-#'   distributed half Student t with degrees of freedom \code{global_df} and 
-#'   scale \code{global_scale}.
+#'   a regularized horseshoe prior, as described by Piironen and Vehtari (2017),
+#'   which recommends setting the \code{global_scale} argument equal to the ratio
+#'   of the expected number of non-zero coefficients to the expected number of
+#'   zero coefficients, divided by the square root of the number of observations.
 #'   
-#'   The hierarhical shrinkpage plus (\code{hs_plus}) prior is a normal with a 
-#'   mean of zero and a standard deviation that is distributed as the product of
-#'   two independent half Student t parameters (both with \eqn{3} degrees of
-#'   freedom (\code{df1}, \code{df2}) by default) that are each scaled in a
-#'   similar way to the \code{hs} prior.
+#'   The hierarhical shrinkpage plus (\code{hs_plus}) prior is similar except 
+#'   that the standard deviation that is distributed as the product of two 
+#'   independent half Cauchy parameters that are each scaled in a similar way
+#'   to the \code{hs} prior.
 #'   
 #'   The hierarchical shrinkage priors have very tall modes and very fat tails.
 #'   Consequently, they tend to produce posterior distributions that are very
@@ -242,6 +238,7 @@
 #'   Family members:
 #'   \itemize{
 #'   \item \code{decov(regularization, concentration, shape, scale)}
+#'   \item \code{lkj(regularization, scale, df)}
 #'   }
 #'   (Also see vignette for \code{stan_glmer})
 #'   
@@ -296,6 +293,27 @@
 #'   \code{concentration} parameters, but does have \code{shape} and 
 #'   \code{scale} parameters for the prior standard deviation of that 
 #'   variable.
+#'   
+#'   Note that for \code{\link{stan_mvmer}} and \code{\link{stan_jm}} models an
+#'   additional prior distribution is provided through the \code{lkj} function.
+#'   This prior is in fact currently used as the default for those modelling
+#'   functions (although \code{decov} is still available as an option if the user
+#'   wishes to specify it through the \code{prior_covariance} argument). The
+#'   \code{lkj} prior uses the same decomposition of the covariance matrices
+#'   into correlation matrices and variances, however, the variances are not
+#'   further decomposed into a simplex vector and the trace; instead the 
+#'   standard deviations (square root of the variances) for each of the group
+#'   specific parameters are given a half Student t distribution with the 
+#'   scale and df parameters specified through the \code{scale} and \code{df}
+#'   arguments to the \code{lkj} function. The scale parameter default is 10
+#'   which is then autoscaled, whilst the df parameter default is 1 
+#'   (therefore equivalent to a half Cauchy prior distribution for the 
+#'   standard deviation of each group specific parameter). This prior generally
+#'   leads to similar results as the \code{decov} prior, but it is also likely
+#'   to be **less** diffuse compared with the \code{decov} prior; therefore it 
+#'   sometimes seems to lead to faster estimation times, hence why it has
+#'   been chosen as the default prior for \code{\link{stan_mvmer}} and 
+#'   \code{\link{stan_jm}} where estimation times can be long.
 #' }
 #' \subsection{R2 family}{
 #'   Family members:
@@ -428,22 +446,30 @@ cauchy <- function(location = 0, scale = NULL, autoscale = TRUE) {
 
 #' @rdname priors
 #' @export
-hs <- function(df = 3, global_df = 1, global_scale = 1) {
+hs <- function(df = 1, global_df = 1, global_scale = 0.01,
+               slab_df = 4, slab_scale = 2.5) {
   validate_parameter_value(df)
   validate_parameter_value(global_df)
   validate_parameter_value(global_scale)
-  nlist(dist = "hs", df, location = 0, scale = 1, global_df, global_scale)
+  validate_parameter_value(slab_df)
+  validate_parameter_value(slab_scale)
+  nlist(dist = "hs", df, location = 0, scale = 1, 
+        global_df, global_scale, slab_df, slab_scale)
 }
 
 #' @rdname priors
 #' @export
-hs_plus <- function(df1 = 3, df2 = 3, global_df = 1, global_scale = 1) {
+hs_plus <- function(df1 = 1, df2 = 1, global_df = 1, global_scale = 0.01,
+                    slab_df = 4, slab_scale = 2.5) {
   validate_parameter_value(df1)
   validate_parameter_value(df2)
   validate_parameter_value(global_df)
   validate_parameter_value(global_scale)
+  validate_parameter_value(slab_df)
+  validate_parameter_value(slab_scale)
   # scale gets used as a second df hyperparameter
-  nlist(dist = "hs_plus", df = df1, location = 0, scale = df2, global_df, global_scale)
+  nlist(dist = "hs_plus", df = df1, location = 0, scale = df2, global_df, 
+        global_scale, slab_df, slab_scale)
 }
 
 #' @rdname priors
@@ -462,7 +488,7 @@ lasso <- function(df = 1, location = 0, scale = NULL, autoscale = TRUE) {
 #' @export
 product_normal <- function(df = 2, location = 0, scale = 1) {
   validate_parameter_value(df)
-  stopifnot(all(df >= 2), all(df == as.integer(df)))
+  stopifnot(all(df >= 1), all(df == as.integer(df)))
   validate_parameter_value(scale)
   nlist(dist = "product_normal", df, location, scale)
 }
@@ -484,8 +510,8 @@ exponential <- function(rate = 1, autoscale = TRUE) {
 #' @rdname priors
 #' @export
 #' @param regularization Exponent for an LKJ prior on the correlation matrix in
-#'   the \code{decov} prior. The default is \eqn{1}, implying a joint uniform
-#'   prior.
+#'   the \code{decov} or \code{lkj} prior. The default is \eqn{1}, implying a 
+#'   joint uniform prior.
 #' @param concentration Concentration parameter for a symmetric Dirichlet 
 #'   distribution. The default is \eqn{1}, implying a joint uniform prior.
 #' @param shape Shape parameter for a gamma prior on the scale parameter in the
@@ -501,6 +527,15 @@ decov <- function(regularization = 1, concentration = 1,
   nlist(dist = "decov", regularization, concentration, shape, scale)
 }
 
+#' @rdname priors
+#' @export
+lkj <- function(regularization = 1, scale = 10, df = 1, autoscale = TRUE) {
+  validate_parameter_value(regularization)
+  validate_parameter_value(scale)
+  validate_parameter_value(df)
+  nlist(dist = "lkj", regularization, scale, df, autoscale)
+}
+
 #' @rdname priors
 #' @export
 dirichlet <- function(concentration = 1) {
