@@ -24,8 +24,8 @@ ITER <- 10
 CHAINS <- 2
 CORES <- 1
 
-source(file.path("helpers", "SW.R"))
-source(file.path("helpers", "expect_gg.R"))
+source(test_path("helpers", "SW.R"))
+source(test_path("helpers", "expect_gg.R"))
 
 fit <- example_model
 SW(fito <- stan_glm(mpg ~ ., data = mtcars, algorithm = "optimizing", seed = SEED))
